# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_validate_api_client
from cloudmersive_validate_api_client.models.sql_injection_detection_result import SqlInjectionDetectionResult  # noqa: E501
from cloudmersive_validate_api_client.rest import ApiException


class TestSqlInjectionDetectionResult(unittest.TestCase):
    """SqlInjectionDetectionResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSqlInjectionDetectionResult(self):
        """Test SqlInjectionDetectionResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cloudmersive_validate_api_client.models.sql_injection_detection_result.SqlInjectionDetectionResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
