# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PhoneNumberValidateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'phone_number': 'str',
        'default_country_code': 'str'
    }

    attribute_map = {
        'phone_number': 'PhoneNumber',
        'default_country_code': 'DefaultCountryCode'
    }

    def __init__(self, phone_number=None, default_country_code=None):  # noqa: E501
        """PhoneNumberValidateRequest - a model defined in Swagger"""  # noqa: E501

        self._phone_number = None
        self._default_country_code = None
        self.discriminator = None

        if phone_number is not None:
            self.phone_number = phone_number
        if default_country_code is not None:
            self.default_country_code = default_country_code

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneNumberValidateRequest.  # noqa: E501

        Raw phone number string to parse as input for validation  # noqa: E501

        :return: The phone_number of this PhoneNumberValidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneNumberValidateRequest.

        Raw phone number string to parse as input for validation  # noqa: E501

        :param phone_number: The phone_number of this PhoneNumberValidateRequest.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def default_country_code(self):
        """Gets the default_country_code of this PhoneNumberValidateRequest.  # noqa: E501

        Optional, default country code.  If left blank, will default to \"US\".  # noqa: E501

        :return: The default_country_code of this PhoneNumberValidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._default_country_code

    @default_country_code.setter
    def default_country_code(self, default_country_code):
        """Sets the default_country_code of this PhoneNumberValidateRequest.

        Optional, default country code.  If left blank, will default to \"US\".  # noqa: E501

        :param default_country_code: The default_country_code of this PhoneNumberValidateRequest.  # noqa: E501
        :type: str
        """

        self._default_country_code = default_country_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PhoneNumberValidateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumberValidateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
