# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_validate_api_client
from cloudmersive_validate_api_client.api.date_time_api import DateTimeApi  # noqa: E501
from cloudmersive_validate_api_client.rest import ApiException


class TestDateTimeApi(unittest.TestCase):
    """DateTimeApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_validate_api_client.api.date_time_api.DateTimeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_date_time_get_now_simple(self):
        """Test case for date_time_get_now_simple

        Get current date and time as of now  # noqa: E501
        """
        pass

    def test_date_time_get_public_holidays(self):
        """Test case for date_time_get_public_holidays

        Get public holidays in the specified country and year  # noqa: E501
        """
        pass

    def test_date_time_parse_natural_language_date_time(self):
        """Test case for date_time_parse_natural_language_date_time

        Parses a free-form natural language date and time string into a date and time  # noqa: E501
        """
        pass

    def test_date_time_parse_standard_date_time(self):
        """Test case for date_time_parse_standard_date_time

        Parses a standardized date and time string into a date and time  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
