# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.vat_api import VatApi  # noqa: E501
from swagger_client.rest import ApiException


class TestVatApi(unittest.TestCase):
    """VatApi unit test stubs"""

    def setUp(self):
        self.api = swagger_client.api.vat_api.VatApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_vat_vat_lookup(self):
        """Test case for vat_vat_lookup

        Lookup a VAT code  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
