# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DateTimeNowResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'now': 'datetime',
        'now_gmt': 'datetime'
    }

    attribute_map = {
        'successful': 'Successful',
        'now': 'Now',
        'now_gmt': 'NowGmt'
    }

    def __init__(self, successful=None, now=None, now_gmt=None):  # noqa: E501
        """DateTimeNowResult - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._now = None
        self._now_gmt = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if now is not None:
            self.now = now
        if now_gmt is not None:
            self.now_gmt = now_gmt

    @property
    def successful(self):
        """Gets the successful of this DateTimeNowResult.  # noqa: E501

        True if successful, false otherwise  # noqa: E501

        :return: The successful of this DateTimeNowResult.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this DateTimeNowResult.

        True if successful, false otherwise  # noqa: E501

        :param successful: The successful of this DateTimeNowResult.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def now(self):
        """Gets the now of this DateTimeNowResult.  # noqa: E501

        Current date, time, and time zone in standard JSON date format  # noqa: E501

        :return: The now of this DateTimeNowResult.  # noqa: E501
        :rtype: datetime
        """
        return self._now

    @now.setter
    def now(self, now):
        """Sets the now of this DateTimeNowResult.

        Current date, time, and time zone in standard JSON date format  # noqa: E501

        :param now: The now of this DateTimeNowResult.  # noqa: E501
        :type: datetime
        """

        self._now = now

    @property
    def now_gmt(self):
        """Gets the now_gmt of this DateTimeNowResult.  # noqa: E501

        Current GMT-time-zone date, time, and time zone in standard JSON date format  # noqa: E501

        :return: The now_gmt of this DateTimeNowResult.  # noqa: E501
        :rtype: datetime
        """
        return self._now_gmt

    @now_gmt.setter
    def now_gmt(self, now_gmt):
        """Sets the now_gmt of this DateTimeNowResult.

        Current GMT-time-zone date, time, and time zone in standard JSON date format  # noqa: E501

        :param now_gmt: The now_gmt of this DateTimeNowResult.  # noqa: E501
        :type: datetime
        """

        self._now_gmt = now_gmt

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DateTimeNowResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DateTimeNowResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
